<?php
namespace AkTest\Lib\File;

use Ak\Lib\File\File;
use PHPUnit\Framework\TestCase;

/**
 * Class FileTest
 *
 * @package AkTest\File
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/file
 */
final class FileTest extends TestCase
{
    public function testCanGetContentsIfStreamIsSet()
    {
        $stream = fopen('php://memory', 'w');
        fwrite($stream, 'some content');
        rewind($stream);
        $file = new File($stream);

        $this->assertEquals('some content', $file->getContents());
    }

    public function testCanGetStreamIfContentsIsSet()
    {
        $file = new File('some content');
        $stream = $file->getStream();

        $this->assertIsResource($stream);
        $this->assertEquals(12, fstat($stream)['size']);
        $this->assertEquals('some content', stream_get_contents($stream));
    }

    public function testCanGetMd5Hash()
    {
        $file = new File('some content');
        $this->assertEquals(md5('some content'), $file->getMd5Hash());
    }

    public function testCanDetectImageGif()
    {
        $path = __DIR__ . '/data/image.gif';
        $file = new File(fopen($path, 'r'));

        $this->assertEquals('image/gif', $file->getMimeType());
    }

    public function testCanDetectImageJpeg()
    {
        $path = __DIR__ . '/data/image.jpg';
        $file = new File(file_get_contents($path));

        $this->assertEquals('image/jpeg', $file->getMimeType());
    }

    public function testCanDetectImagePng()
    {
        $path = __DIR__ . '/data/image.png';
        $file = new File(fopen($path, 'r'));

        $this->assertEquals('image/png', $file->getMimeType());
    }

    public function testCanDetectPlainText()
    {
        $path = __DIR__ . '/data/file.txt';
        $file = new File(fopen($path, 'r'));

        $this->assertEquals('text/plain', $file->getMimeType());
    }

    public function testWillCloseTheStreamOnDestruct()
    {
        $stream = fopen(__DIR__ . '/data/script.sh', 'r');
        /** @noinspection PhpUnusedLocalVariableInspection */
        $file = new File($stream);

        $this->assertIsResource($stream);
        $file = null;
        $this->assertFalse(is_resource($stream));
    }

    public function testCanSetNameViaTheConstructor()
    {
        $file = new File(null, 'filename.txt');
        $this->assertEquals('filename.txt', $file->getName());
    }

    public function testCanChangeTheFileName()
    {
        $file = new File(null, 'filename.txt');
        $file->setName('othername.txt');
        $this->assertEquals('othername.txt', $file->getName());
    }
}